package beans;

import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import javax.annotation.PostConstruct;
import javax.enterprise.context.RequestScoped;
import javax.faces.context.FacesContext;
import javax.inject.Named;

@Named
@RequestScoped
public class Bb {
    /* 日本、アメリカ、ドイツに対応するので、その国記号付きのロケール
     * setLocaleメソッドで使う
    */
    private static final Locale[] locales = {Locale.JAPAN, Locale.GERMANY, Locale.US};
    
    /* １件だけ用意したデータです。本来はデータベースにいれておくものですが、
     * 簡単にしました。
     * static にしてあらかじめ作っておきます。
     */
    private static Book book;
    static{
        Map<String, String> titles = new HashMap();
        titles.put(Locale.JAPANESE.toString(), "わかりやすいJavaEE");
        titles.put(Locale.ENGLISH.toString(), "Descriptive JavaEE");
        titles.put(Locale.GERMAN.toString(), "Beschreibende JavaEE");

        titles.put(Locale.JAPAN.toString(), "わかりやすいJavaEE");
        titles.put(Locale.US.toString(), "Descriptive JavaEE");
        titles.put(Locale.GERMANY.toString(), "Beschreibende JavaEE");
        
        Map<String, Integer> prices = new HashMap();
        prices.put(Locale.JAPANESE.toString(), 3200);
        prices.put(Locale.ENGLISH.toString(), 24);
        prices.put(Locale.GERMAN.toString(), 27);

        prices.put(Locale.JAPAN.toString(), 3200);
        prices.put(Locale.US.toString(), 24);
        prices.put(Locale.GERMANY.toString(), 27);

        book = new Book("9784798042169", titles, prices);        
    }
    
    private String title;       // 書籍の名前
    private Integer price;      // 価格
    
    /* ウェブで国旗のアイコンをクリックすると、指定されたロケール記号を持ち
    　 ここへ来る。ロケールを切り替え、データもロケールに合わせて入れ替えます。
       voidなので、終了後、画面が再表示されます。
    */
    public void setLocale(String localeStr) {
        for (Locale lo : locales) {
            if (localeStr.equals(lo.toString())) {
                FacesContext.getCurrentInstance().getViewRoot().setLocale(lo);
                title = book.getTitle().get(lo.toString());
                price = book.getPrice().get(lo.toString());
                break;
            }
        }
    }

    /* コンストラクタの終了直後に実行するライフサイクル・コールバックメソッド 
     * （わかりやすいJavaの14章を参照）
     * ブラウザのロケ－ル設定を受け取り、初期表示データをローケルに合わせてセットする
     * また、言語だけのロケールだったら、国記号付きに変えてセットしなおす
    */
    @PostConstruct
    public void init() {
        Locale locale = FacesContext.getCurrentInstance().getViewRoot().getLocale();
        this.title = book.getTitle().get(locale.toString());
        this.price = book.getPrice().get(locale.toString());
        
        /* 言語コードだけでは、通貨記号を表示できないので、国記号付きに変更する */
        if(locale.equals(Locale.JAPANESE))  chgLocale(Locale.JAPAN);
        else if(locale.equals(Locale.GERMAN))  chgLocale(Locale.GERMANY);
        else if(locale.equals(Locale.ENGLISH))  chgLocale(Locale.US);
    }
    public void chgLocale(Locale locale){
         FacesContext.getCurrentInstance().getViewRoot().setLocale(locale);
    }
    
    /* セッターとゲッター */
    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getPrice() {
        return price;
    }

    public void setPrice(Integer price) {
        this.price = price;
    }
}
